/**
 * Copyright (c) 2021 CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *  Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - initial API and implementation
 *   Etienne ALLOGO (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : generate less dead or duplicate code
 */
package impl.diagram.editparts;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenCommonBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.papyrus.gmf.codegen.gmfgen.LabelModelFacet;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.CodeStyle;
import xpt.Common;
import xpt.diagram.ViewmapAttributesUtils_qvto;
import xpt.providers.ElementTypes;

@Singleton
@SuppressWarnings("all")
public class TextAwareExtent {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  @Extension
  private CodeStyle _codeStyle;
  
  @Inject
  @Extension
  private ViewmapAttributesUtils_qvto _viewmapAttributesUtils_qvto;
  
  @Inject
  private ElementTypes xptElementTypes;
  
  public CharSequence methodsExtent(final GenCommonBase it, final boolean needsRefreshBounds, final boolean readOnly, final LabelModelFacet modelFacet, final GenCommonBase host) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _parserElementNullModelFacet = this.getParserElementNullModelFacet(it, modelFacet);
    _builder.append(_parserElementNullModelFacet);
    _builder.newLineIfNotEmpty();
    CharSequence _isEditableReadOnly = this.isEditableReadOnly(it, readOnly);
    _builder.append(_isEditableReadOnly);
    _builder.newLineIfNotEmpty();
    CharSequence _parser = this.getParser(it, host);
    _builder.append(_parser);
    _builder.newLineIfNotEmpty();
    CharSequence _refreshVisualsNeedRefreshBounds = this.refreshVisualsNeedRefreshBounds(it, needsRefreshBounds);
    _builder.append(_refreshVisualsNeedRefreshBounds);
    _builder.newLineIfNotEmpty();
    CharSequence _fontStyleOwnerViewFixedFont = this.getFontStyleOwnerViewFixedFont(it);
    _builder.append(_fontStyleOwnerViewFixedFont);
    _builder.newLineIfNotEmpty();
    CharSequence _directEditionTypeReadOnly = this.getDirectEditionTypeReadOnly(it, readOnly);
    _builder.append(_directEditionTypeReadOnly);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence getParserElementNullModelFacet(final GenCommonBase it, final LabelModelFacet modelFacet) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((modelFacet == null)) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("protected org.eclipse.emf.ecore.EObject getParserElement() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("org.eclipse.emf.ecore.EObject element = resolveSemanticElement();");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return element != null ? element : (org.eclipse.gmf.runtime.notation.View) getModel();");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence getLabelIconNotUseElementIcon(final GenCommonBase it, final boolean useElementIcon, final GenDiagram diagram) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((!useElementIcon)) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideI = this._codeStyle.overrideI(it);
        _builder.append(_overrideI);
        _builder.newLineIfNotEmpty();
        _builder.append("protected org.eclipse.swt.graphics.Image getLabelIcon() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("// not use element icon");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return null;");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence refreshVisualsNeedRefreshBounds(final GenCommonBase it, final boolean needsRefreshBounds) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if (needsRefreshBounds) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("protected void refreshVisuals() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("super.refreshVisuals();");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("refreshBounds();");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence getFontStyleOwnerViewFixedFont(final GenCommonBase it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _isFixedFont = this._viewmapAttributesUtils_qvto.isFixedFont(it.getViewmap());
      if (_isFixedFont) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("protected View getFontStyleOwnerView() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return (org.eclipse.gmf.runtime.notation.View) getModel();");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence getDirectEditionTypeReadOnly(final GenCommonBase it, final boolean readOnly) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if (readOnly) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("public int getDirectEditionType() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("// The label is read-only (defined in GMFGen model)");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return org.eclipse.papyrus.uml.diagram.common.editpolicies.IDirectEdition.NO_DIRECT_EDITION;");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence isEditableReadOnly(final GenCommonBase it, final boolean readOnly) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if (readOnly) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("protected boolean isEditable() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return false;");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence getParser(final GenCommonBase it, final GenCommonBase host) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    CharSequence _overrideC = this._codeStyle.overrideC(it);
    _builder.append(_overrideC);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.gmf.runtime.common.ui.services.parser.IParser getParser() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (parser == null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("parser = org.eclipse.papyrus.infra.gmfdiag.common.parsers.ParserUtil.getParser(");
    CharSequence _accessElementType = this.xptElementTypes.accessElementType(host);
    _builder.append(_accessElementType, "\t\t");
    _builder.append(", getParserElement(), this, VISUAL_ID);");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return parser;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}
